==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking1/dialogs_nl.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Dit is vast een Vikingschip!")


dialogId("dr-v-jiste", "font_big", "Sure, it`s a drakkar.")
dialogStr("Natuurlijk, het is een drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Die moet heel snel gezonken zijn. De roeiers zitten nog op hun plek.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Misschien hebben ze haar wel expres laten zinken. Krijgers begeleidden vroeger hun leider op zijn weg naar Valhalla.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Dat is vreselijk. Ze zien er bijna uit alsof ze nog leven.")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("De muziek is weg!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Ze zijn opgehouden met spelen!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("De muziek is alweer opgehouden!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("O, nee!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Alweer?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("O, nee, niet weer!")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Wat is er gebeurd?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Alweer?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("O, nee!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Die rotmuziek is alweer opgehouden!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Wat voeren die lui daarboven toch uit?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Hoe kan dat nou?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Geen zorgen, jongens. Solo voor Olaf!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Let maar niet op, jongens. We kunnen zelf ook wel zingen!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Maakt niet uit, jongens. We kunnen zelf ook zingen, net als vroeger!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking1/dialogs_nl.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Dit is vast een vikingschip!")


dialogId("dr-v-jiste", "font_big", "Sure, it’s a drakkar.")
dialogStr("Natuurlijk, het is een drakhar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Ze moet heel snel gezonken zijn. De roeiers zitten nog op hun plek.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Misschien hebben ze haar wel expres laten zinken. Krijgers begeleidden vroeger hun leider op zijn weg naar Valhalla.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Dat is vreselijk. Ze zien er bijna uit alsof ze nog leven.")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("De muziek is weg!")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Ze zijn opgehouden met spelen!")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("De muziek is alweer opgehouden!")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("O, nee!")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Alweer?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("O, nee, niet weer!")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Wat is er gebeurd?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Alweer?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("O, nee!")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Die rotmuziek is alweer opgehouden!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Wat voeren die lui daarboven toch uit?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Hoe kan dat nou?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Geen zorgen, jongens. Solo voor Olaf!")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Let er maar niet op, jongens. We kunnen zelf ook wel zingen!")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Maakt niet uit, jongens. We kunnen zelf ook zingen, net als vroeger!")
